Third Party Applications — Django Grappelli 2.5.0 documentation

### Navigation

- index
- next |
- previous |
- Django Grappelli 2.5.0 documentation »

# Third Party Applications

A list of 3rd-party applications compatible with Grappelli.

## Django FileBrowser

No additional setup is needed when installing the Django FileBrowser with Grappelli.

## Django Reversion

New in version 2.4.

Grappelli includes all necessary templates for Django Reversion.

Note

`grappelli` needs to be before `reversion` within `INSTALLED_APPS`.

## Django Smuggler

New in version 2.4.

Grappelli includes all necessary templates for Django Smuggler.

Note

`grappelli` needs to be before `smuggler` within `INSTALLED_APPS`.

## Django Constance

New in version 2.4.

Grappelli includes the necessary template for Django Constance.

Note

`grappelli` needs to be before `constance` within `INSTALLED_APPS`.

### Navigation

- index
- next |
- previous |
- Django Grappelli 2.5.0 documentation »